@@ -70,7 +70,7 @@ def init_db():
         print(Child.query.filter(Child.id==0).first())
         db.session.add(Child(unique_id="self",id=0))
         db.session.commit()
-    db_actions={1:_v1,2:_v2,3:_v3,6:_v6,8:_v8,9:_v9,10:_v10,11:_v11,12:_v12,13:_v13,14:_v14,16:_v16,17:_v17}
+    db_actions={1:_v1,2:_v2,3:_v3,6:_v6,8:_v8,9:_v9,10:_v10,11:_v11,12:_v12,13:_v13,14:_v14,16:_v16,17:_v17,19:_v19}
     for ver,db_action in db_actions.items():
         if ver<=db_version:continue
         if start_version==0 and ver==10:continue
@@ -88,6 +88,17 @@ def init_db():
     db.session.commit()
     return BoolConfig.query.all()
 
+def _v19():
+    set_hconfig(ConfigEnum.path_trojan,get_random_string(7,15))
+    set_hconfig(ConfigEnum.path_vless,get_random_string(7,15))
+    set_hconfig(ConfigEnum.path_vmess,get_random_string(7,15))
+    set_hconfig(ConfigEnum.path_ss,get_random_string(7,15))
+
+    set_hconfig(ConfigEnum.path_grpc,get_random_string(7,15))
+    set_hconfig(ConfigEnum.path_tcp,get_random_string(7,15))
+    set_hconfig(ConfigEnum.path_ws,get_random_string(7,15))
+    
+
 def _v17():
     for u in User.query.all():
         if u.expiry_time:
@@ -138,9 +149,9 @@ def _v11():
     
 
 
-def get_random_string():
+def get_random_string(min_=10,max_=30):
     # With combination of lower and upper case
-    length=random.randint(10, 30)
+    length=random.randint(min_, max_)
     characters = string.ascii_letters + string.digits
     result_str = ''.join(random.choice(characters) for i in range(length))
     return result_str
