@@ -1,4 +1,6 @@
 from hiddifypanel.panel.restapi.tgbot import  bot,register_bot
 
 from . import Usage
+from . import information
+from . import admin
 from . import DefaultResponse
\ No newline at end of file
